@@ -14,6 +14,7 @@ from ..options import (
     COOKIE_CONSENT_DESCRIPTION,
     COOKIE_CONSENT_BUTTON_ACCEPT,
     COOKIE_CONSENT_BUTTON_ACCEPT_ALL,
+    COOKIE_CONSENT_BUTTON_DETAILS,
     COOKIE_CONSENT_BUTTON_SETTINGS,
     COOKIE_CONSENT_BUTTON_DECLINE,
 )
@@ -26,6 +27,10 @@ from ..extras import (
     get_cookie_modal_extras,
 )
 
+from ..panels import (
+    init_cookie_panels,
+)
+
 class CookieConsentNode(Node):
     def __init__(self, nodelist, args):
         self.nodelist = nodelist
@@ -78,6 +83,15 @@ def render_with_context(context, item):
 def cookie_consent(context):
     request = context["request"]
 
+    action_url = reverse("cookie_consent:submit")
+    policy_url = reverse("cookie_consent:policy")
+
+    # if request.path.lower().strip("/") == policy_url.lower().strip("/"):
+    #     return ""
+
+    cookie_panels = init_cookie_panels(request)
+    cookie_form = make_consent_form(request, cookie_panels=cookie_panels)
+
     if not request.cookie_consent.submitted:
 
         cookie_ctx = {
@@ -88,14 +102,17 @@ def cookie_consent(context):
             "cookie_modal_logo_url":    COOKIE_CONSENT_LOGO_URL,
             "cookie_modal_title":       COOKIE_CONSENT_TITLE,
             "cookie_modal_description": COOKIE_CONSENT_DESCRIPTION,
-            "cookie_modal_form_action": reverse("cookie_consent:submit"),
-            "cookie_modal_form":        make_consent_form(request),
+            "cookie_modal_form_action": action_url,
+            "cookie_modal_policy_url":  policy_url,
+            "cookie_modal_form":        cookie_form,
+            "cookie_modal_panels":      cookie_panels,
             "cookie_modal_extras":      get_cookie_modal_extras(request),
 
             "cookie_modal_accept_all_value": ACCEPT_ALL_COOKIE,
 
             "cookie_modal_button_accept":     COOKIE_CONSENT_BUTTON_ACCEPT,
             "cookie_modal_button_accept_all": COOKIE_CONSENT_BUTTON_ACCEPT_ALL,
+            "cookie_modal_button_details":    COOKIE_CONSENT_BUTTON_DETAILS,
             "cookie_modal_button_settings":   COOKIE_CONSENT_BUTTON_SETTINGS,
             "cookie_modal_button_decline":    COOKIE_CONSENT_BUTTON_DECLINE,
         }
